# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .health import (
    HealthResource,
    AsyncHealthResource,
    HealthResourceWithRawResponse,
    AsyncHealthResourceWithRawResponse,
    HealthResourceWithStreamingResponse,
    AsyncHealthResourceWithStreamingResponse,
)
from .call_analysis import (
    CallAnalysisResource,
    AsyncCallAnalysisResource,
    CallAnalysisResourceWithRawResponse,
    AsyncCallAnalysisResourceWithRawResponse,
    CallAnalysisResourceWithStreamingResponse,
    AsyncCallAnalysisResourceWithStreamingResponse,
)

__all__ = [
    "HealthResource",
    "AsyncHealthResource",
    "HealthResourceWithRawResponse",
    "AsyncHealthResourceWithRawResponse",
    "HealthResourceWithStreamingResponse",
    "AsyncHealthResourceWithStreamingResponse",
    "CallAnalysisResource",
    "AsyncCallAnalysisResource",
    "CallAnalysisResourceWithRawResponse",
    "AsyncCallAnalysisResourceWithRawResponse",
    "CallAnalysisResourceWithStreamingResponse",
    "AsyncCallAnalysisResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["CallAnalysisCreateResponse", "Data", "DataCall", "DataCallParticipant"]


class DataCallParticipant(BaseModel):
    role: Literal["AGENT", "CUSTOMER"]

    is_simulated: Optional[bool] = FieldInfo(alias="isSimulated", default=None)

    name: Optional[str] = None

    phone_number: Optional[str] = FieldInfo(alias="phoneNumber", default=None)

    spoke_first: Optional[bool] = FieldInfo(alias="spokeFirst", default=None)


class DataCall(BaseModel):
    id: str

    call_direction: Literal["INBOUND", "OUTBOUND"] = FieldInfo(alias="callDirection")

    is_test: bool = FieldInfo(alias="isTest")

    participants: List[DataCallParticipant]

    started_at: str = FieldInfo(alias="startedAt")

    status: Optional[Literal["RINGING", "IN_PROGRESS", "ENDED"]] = None

    duration_ms: Optional[float] = FieldInfo(alias="durationMs", default=None)

    ended_at: Optional[str] = FieldInfo(alias="endedAt", default=None)

    ended_reason: Optional[str] = FieldInfo(alias="endedReason", default=None)

    properties: Optional[Dict[str, object]] = None

    summary: Optional[str] = None


class Data(BaseModel):
    call: DataCall

    job_id: str = FieldInfo(alias="jobId")
    """Analysis job ID for tracking progress"""

    status: Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]


class CallAnalysisCreateResponse(BaseModel):
    data: Data
    """Analysis job with associated call context"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from roark_analytics import Roark, AsyncRoark
from roark_analytics.types import CallAnalysisCreateResponse, CallAnalysisRetrieveResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCallAnalysis:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Roark) -> None:
        call_analysis = client.call_analysis.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[{"role": "AGENT"}, {"role": "CUSTOMER"}],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
        )
        assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: Roark) -> None:
        call_analysis = client.call_analysis.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[
                {
                    "role": "AGENT",
                    "is_simulated": True,
                    "name": "Sales Agent",
                    "phone_number": "+15551234567",
                    "spoke_first": True,
                },
                {
                    "role": "CUSTOMER",
                    "is_simulated": True,
                    "name": "John Doe",
                    "phone_number": "+15557654321",
                    "spoke_first": False,
                },
            ],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
            ended_reason="endedReason",
            ended_status="AGENT_ENDED_CALL",
            is_test=False,
            properties={
                "business_name": "bar",
                "business_id": "bar",
            },
            retell_call_id="retellCallId",
            stereo_recording_url="https://example.com",
            tool_invocations=[
                {
                    "name": "getDentalAppointments",
                    "parameters": {},
                    "result": {"appointments": "bar"},
                    "start_offset_ms": 2000,
                    "description": "Get available dental appointments",
                    "end_offset_ms": 0,
                },
                {
                    "name": "bookAppointment",
                    "parameters": {
                        "patientName": "John Doe",
                        "patientPhone": "+1234567890",
                        "appointmentType": {
                            "description": "Type of dental appointment",
                            "type": "string",
                            "value": "cleaning",
                        },
                    },
                    "result": "Success",
                    "start_offset_ms": 7000,
                    "description": "Book an appointment for the client",
                    "end_offset_ms": 0,
                },
            ],
            vapi_call_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Roark) -> None:
        response = client.call_analysis.with_raw_response.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[{"role": "AGENT"}, {"role": "CUSTOMER"}],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call_analysis = response.parse()
        assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Roark) -> None:
        with client.call_analysis.with_streaming_response.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[{"role": "AGENT"}, {"role": "CUSTOMER"}],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call_analysis = response.parse()
            assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Roark) -> None:
        call_analysis = client.call_analysis.retrieve(
            "jobId",
        )
        assert_matches_type(CallAnalysisRetrieveResponse, call_analysis, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Roark) -> None:
        response = client.call_analysis.with_raw_response.retrieve(
            "jobId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call_analysis = response.parse()
        assert_matches_type(CallAnalysisRetrieveResponse, call_analysis, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Roark) -> None:
        with client.call_analysis.with_streaming_response.retrieve(
            "jobId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call_analysis = response.parse()
            assert_matches_type(CallAnalysisRetrieveResponse, call_analysis, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Roark) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `job_id` but received ''"):
            client.call_analysis.with_raw_response.retrieve(
                "",
            )


class TestAsyncCallAnalysis:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncRoark) -> None:
        call_analysis = await async_client.call_analysis.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[{"role": "AGENT"}, {"role": "CUSTOMER"}],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
        )
        assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncRoark) -> None:
        call_analysis = await async_client.call_analysis.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[
                {
                    "role": "AGENT",
                    "is_simulated": True,
                    "name": "Sales Agent",
                    "phone_number": "+15551234567",
                    "spoke_first": True,
                },
                {
                    "role": "CUSTOMER",
                    "is_simulated": True,
                    "name": "John Doe",
                    "phone_number": "+15557654321",
                    "spoke_first": False,
                },
            ],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
            ended_reason="endedReason",
            ended_status="AGENT_ENDED_CALL",
            is_test=False,
            properties={
                "business_name": "bar",
                "business_id": "bar",
            },
            retell_call_id="retellCallId",
            stereo_recording_url="https://example.com",
            tool_invocations=[
                {
                    "name": "getDentalAppointments",
                    "parameters": {},
                    "result": {"appointments": "bar"},
                    "start_offset_ms": 2000,
                    "description": "Get available dental appointments",
                    "end_offset_ms": 0,
                },
                {
                    "name": "bookAppointment",
                    "parameters": {
                        "patientName": "John Doe",
                        "patientPhone": "+1234567890",
                        "appointmentType": {
                            "description": "Type of dental appointment",
                            "type": "string",
                            "value": "cleaning",
                        },
                    },
                    "result": "Success",
                    "start_offset_ms": 7000,
                    "description": "Book an appointment for the client",
                    "end_offset_ms": 0,
                },
            ],
            vapi_call_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncRoark) -> None:
        response = await async_client.call_analysis.with_raw_response.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[{"role": "AGENT"}, {"role": "CUSTOMER"}],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call_analysis = await response.parse()
        assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncRoark) -> None:
        async with async_client.call_analysis.with_streaming_response.create(
            call_direction="INBOUND",
            interface_type="WEB",
            participants=[{"role": "AGENT"}, {"role": "CUSTOMER"}],
            recording_url="https://example.com/recording.wav",
            started_at="2025-05-19T00:24:35.065Z",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call_analysis = await response.parse()
            assert_matches_type(CallAnalysisCreateResponse, call_analysis, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncRoark) -> None:
        call_analysis = await async_client.call_analysis.retrieve(
            "jobId",
        )
        assert_matches_type(CallAnalysisRetrieveResponse, call_analysis, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncRoark) -> None:
        response = await async_client.call_analysis.with_raw_response.retrieve(
            "jobId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call_analysis = await response.parse()
        assert_matches_type(CallAnalysisRetrieveResponse, call_analysis, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncRoark) -> None:
        async with async_client.call_analysis.with_streaming_response.retrieve(
            "jobId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call_analysis = await response.parse()
            assert_matches_type(CallAnalysisRetrieveResponse, call_analysis, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncRoark) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `job_id` but received ''"):
            await async_client.call_analysis.with_raw_response.retrieve(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .health_get_response import HealthGetResponse as HealthGetResponse
from .call_analysis_create_params import CallAnalysisCreateParams as CallAnalysisCreateParams
from .call_analysis_create_response import CallAnalysisCreateResponse as CallAnalysisCreateResponse
from .call_analysis_retrieve_response import CallAnalysisRetrieveResponse as CallAnalysisRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["HealthGetResponse", "Data"]


class Data(BaseModel):
    status: Literal["healthy", "degraded", "unhealthy"]

    timestamp: str

    version: str


class HealthGetResponse(BaseModel):
    data: Data
    """Health check response payload"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Literal

import httpx

from ..types import call_analysis_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.call_analysis_create_response import CallAnalysisCreateResponse
from ..types.call_analysis_retrieve_response import CallAnalysisRetrieveResponse

__all__ = ["CallAnalysisResource", "AsyncCallAnalysisResource"]


class CallAnalysisResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CallAnalysisResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/roarkhq/sdk-roark-analytics-python#accessing-raw-response-data-eg-headers
        """
        return CallAnalysisResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CallAnalysisResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/roarkhq/sdk-roark-analytics-python#with_streaming_response
        """
        return CallAnalysisResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        call_direction: Literal["INBOUND", "OUTBOUND"],
        interface_type: Literal["PHONE", "WEB"],
        participants: Iterable[call_analysis_create_params.Participant],
        recording_url: str,
        started_at: str,
        ended_reason: str | NotGiven = NOT_GIVEN,
        ended_status: Literal[
            "AGENT_ENDED_CALL",
            "AGENT_TRANSFERRED_CALL",
            "AGENT_ERROR",
            "CUSTOMER_ENDED_CALL",
            "VOICE_MAIL_REACHED",
            "SILENCE_TIME_OUT",
            "PHONE_CALL_PROVIDER_CONNECTION_ERROR",
            "CUSTOMER_DID_NOT_ANSWER",
            "CUSTOMER_BUSY",
            "DIAL_ERROR",
            "MAX_DURATION_REACHED",
            "UNKNOWN",
        ]
        | NotGiven = NOT_GIVEN,
        is_test: bool | NotGiven = NOT_GIVEN,
        properties: Dict[str, object] | NotGiven = NOT_GIVEN,
        retell_call_id: str | NotGiven = NOT_GIVEN,
        stereo_recording_url: str | NotGiven = NOT_GIVEN,
        tool_invocations: Iterable[call_analysis_create_params.ToolInvocation] | NotGiven = NOT_GIVEN,
        vapi_call_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallAnalysisCreateResponse:
        """
        Upload a new call recording

        Args:
          call_direction: Direction of the call (INBOUND or OUTBOUND)

          interface_type: Interface type of the call (PHONE or WEB)

          participants: Exactly two participants in the call

          recording_url: URL of source recording (must be an accessible WAV or MP3 file). Can be a signed
              URL.

          started_at: When the call started (ISO 8601 format)

          ended_reason: Additional context on why the call terminated with the endedStatus

          ended_status: High-level call end status, indicating how the call terminated

          is_test: Whether this is a test call

          properties: Custom properties to include with the call. These can be used for filtering and
              will show in the call details page

          retell_call_id: Retell call ID if call is being imported from Retell

          stereo_recording_url: URL of source stereo recording in WAV format. Must be accessible. Can be a
              signed URL. While optional it allows for a richer audio player

          tool_invocations: List of tool invocations made during the call

          vapi_call_id: Vapi call ID if call is being imported from Vapi

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/call-analysis",
            body=maybe_transform(
                {
                    "call_direction": call_direction,
                    "interface_type": interface_type,
                    "participants": participants,
                    "recording_url": recording_url,
                    "started_at": started_at,
                    "ended_reason": ended_reason,
                    "ended_status": ended_status,
                    "is_test": is_test,
                    "properties": properties,
                    "retell_call_id": retell_call_id,
                    "stereo_recording_url": stereo_recording_url,
                    "tool_invocations": tool_invocations,
                    "vapi_call_id": vapi_call_id,
                },
                call_analysis_create_params.CallAnalysisCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CallAnalysisCreateResponse,
        )

    def retrieve(
        self,
        job_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallAnalysisRetrieveResponse:
        """
        Fetch a call analysis job by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not job_id:
            raise ValueError(f"Expected a non-empty value for `job_id` but received {job_id!r}")
        return self._get(
            f"/v1/call-analysis/{job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CallAnalysisRetrieveResponse,
        )


class AsyncCallAnalysisResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCallAnalysisResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/roarkhq/sdk-roark-analytics-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCallAnalysisResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCallAnalysisResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/roarkhq/sdk-roark-analytics-python#with_streaming_response
        """
        return AsyncCallAnalysisResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        call_direction: Literal["INBOUND", "OUTBOUND"],
        interface_type: Literal["PHONE", "WEB"],
        participants: Iterable[call_analysis_create_params.Participant],
        recording_url: str,
        started_at: str,
        ended_reason: str | NotGiven = NOT_GIVEN,
        ended_status: Literal[
            "AGENT_ENDED_CALL",
            "AGENT_TRANSFERRED_CALL",
            "AGENT_ERROR",
            "CUSTOMER_ENDED_CALL",
            "VOICE_MAIL_REACHED",
            "SILENCE_TIME_OUT",
            "PHONE_CALL_PROVIDER_CONNECTION_ERROR",
            "CUSTOMER_DID_NOT_ANSWER",
            "CUSTOMER_BUSY",
            "DIAL_ERROR",
            "MAX_DURATION_REACHED",
            "UNKNOWN",
        ]
        | NotGiven = NOT_GIVEN,
        is_test: bool | NotGiven = NOT_GIVEN,
        properties: Dict[str, object] | NotGiven = NOT_GIVEN,
        retell_call_id: str | NotGiven = NOT_GIVEN,
        stereo_recording_url: str | NotGiven = NOT_GIVEN,
        tool_invocations: Iterable[call_analysis_create_params.ToolInvocation] | NotGiven = NOT_GIVEN,
        vapi_call_id: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallAnalysisCreateResponse:
        """
        Upload a new call recording

        Args:
          call_direction: Direction of the call (INBOUND or OUTBOUND)

          interface_type: Interface type of the call (PHONE or WEB)

          participants: Exactly two participants in the call

          recording_url: URL of source recording (must be an accessible WAV or MP3 file). Can be a signed
              URL.

          started_at: When the call started (ISO 8601 format)

          ended_reason: Additional context on why the call terminated with the endedStatus

          ended_status: High-level call end status, indicating how the call terminated

          is_test: Whether this is a test call

          properties: Custom properties to include with the call. These can be used for filtering and
              will show in the call details page

          retell_call_id: Retell call ID if call is being imported from Retell

          stereo_recording_url: URL of source stereo recording in WAV format. Must be accessible. Can be a
              signed URL. While optional it allows for a richer audio player

          tool_invocations: List of tool invocations made during the call

          vapi_call_id: Vapi call ID if call is being imported from Vapi

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/call-analysis",
            body=await async_maybe_transform(
                {
                    "call_direction": call_direction,
                    "interface_type": interface_type,
                    "participants": participants,
                    "recording_url": recording_url,
                    "started_at": started_at,
                    "ended_reason": ended_reason,
                    "ended_status": ended_status,
                    "is_test": is_test,
                    "properties": properties,
                    "retell_call_id": retell_call_id,
                    "stereo_recording_url": stereo_recording_url,
                    "tool_invocations": tool_invocations,
                    "vapi_call_id": vapi_call_id,
                },
                call_analysis_create_params.CallAnalysisCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CallAnalysisCreateResponse,
        )

    async def retrieve(
        self,
        job_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CallAnalysisRetrieveResponse:
        """
        Fetch a call analysis job by ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not job_id:
            raise ValueError(f"Expected a non-empty value for `job_id` but received {job_id!r}")
        return await self._get(
            f"/v1/call-analysis/{job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CallAnalysisRetrieveResponse,
        )


class CallAnalysisResourceWithRawResponse:
    def __init__(self, call_analysis: CallAnalysisResource) -> None:
        self._call_analysis = call_analysis

        self.create = to_raw_response_wrapper(
            call_analysis.create,
        )
        self.retrieve = to_raw_response_wrapper(
            call_analysis.retrieve,
        )


class AsyncCallAnalysisResourceWithRawResponse:
    def __init__(self, call_analysis: AsyncCallAnalysisResource) -> None:
        self._call_analysis = call_analysis

        self.create = async_to_raw_response_wrapper(
            call_analysis.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            call_analysis.retrieve,
        )


class CallAnalysisResourceWithStreamingResponse:
    def __init__(self, call_analysis: CallAnalysisResource) -> None:
        self._call_analysis = call_analysis

        self.create = to_streamed_response_wrapper(
            call_analysis.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            call_analysis.retrieve,
        )


class AsyncCallAnalysisResourceWithStreamingResponse:
    def __init__(self, call_analysis: AsyncCallAnalysisResource) -> None:
        self._call_analysis = call_analysis

        self.create = async_to_streamed_response_wrapper(
            call_analysis.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            call_analysis.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo

__all__ = [
    "CallAnalysisCreateParams",
    "Participant",
    "ToolInvocation",
    "ToolInvocationParameters",
    "ToolInvocationParametersUnionMember0",
]


class CallAnalysisCreateParams(TypedDict, total=False):
    call_direction: Required[Annotated[Literal["INBOUND", "OUTBOUND"], PropertyInfo(alias="callDirection")]]
    """Direction of the call (INBOUND or OUTBOUND)"""

    interface_type: Required[Annotated[Literal["PHONE", "WEB"], PropertyInfo(alias="interfaceType")]]
    """Interface type of the call (PHONE or WEB)"""

    participants: Required[Iterable[Participant]]
    """Exactly two participants in the call"""

    recording_url: Required[Annotated[str, PropertyInfo(alias="recordingUrl")]]
    """URL of source recording (must be an accessible WAV or MP3 file).

    Can be a signed URL.
    """

    started_at: Required[Annotated[str, PropertyInfo(alias="startedAt")]]
    """When the call started (ISO 8601 format)"""

    ended_reason: Annotated[str, PropertyInfo(alias="endedReason")]
    """Additional context on why the call terminated with the endedStatus"""

    ended_status: Annotated[
        Literal[
            "AGENT_ENDED_CALL",
            "AGENT_TRANSFERRED_CALL",
            "AGENT_ERROR",
            "CUSTOMER_ENDED_CALL",
            "VOICE_MAIL_REACHED",
            "SILENCE_TIME_OUT",
            "PHONE_CALL_PROVIDER_CONNECTION_ERROR",
            "CUSTOMER_DID_NOT_ANSWER",
            "CUSTOMER_BUSY",
            "DIAL_ERROR",
            "MAX_DURATION_REACHED",
            "UNKNOWN",
        ],
        PropertyInfo(alias="endedStatus"),
    ]
    """High-level call end status, indicating how the call terminated"""

    is_test: Annotated[bool, PropertyInfo(alias="isTest")]
    """Whether this is a test call"""

    properties: Dict[str, object]
    """Custom properties to include with the call.

    These can be used for filtering and will show in the call details page
    """

    retell_call_id: Annotated[str, PropertyInfo(alias="retellCallId")]
    """Retell call ID if call is being imported from Retell"""

    stereo_recording_url: Annotated[str, PropertyInfo(alias="stereoRecordingUrl")]
    """URL of source stereo recording in WAV format.

    Must be accessible. Can be a signed URL. While optional it allows for a richer
    audio player
    """

    tool_invocations: Annotated[Iterable[ToolInvocation], PropertyInfo(alias="toolInvocations")]
    """List of tool invocations made during the call"""

    vapi_call_id: Annotated[str, PropertyInfo(alias="vapiCallId")]
    """Vapi call ID if call is being imported from Vapi"""


class Participant(TypedDict, total=False):
    role: Required[Literal["AGENT", "CUSTOMER"]]

    is_simulated: Annotated[bool, PropertyInfo(alias="isSimulated")]

    name: Optional[str]

    phone_number: Annotated[Optional[str], PropertyInfo(alias="phoneNumber")]

    spoke_first: Annotated[bool, PropertyInfo(alias="spokeFirst")]


class ToolInvocationParametersUnionMember0(TypedDict, total=False):
    description: str

    type: Literal["string", "number", "boolean"]

    value: object


ToolInvocationParameters: TypeAlias = Union[ToolInvocationParametersUnionMember0, object]


class ToolInvocation(TypedDict, total=False):
    name: Required[str]
    """Name of the tool that was invoked"""

    parameters: Required[Dict[str, ToolInvocationParameters]]
    """Parameters provided to the tool during invocation"""

    result: Required[Union[str, Dict[str, object]]]
    """Result returned by the tool after execution. Can be a string or a JSON object"""

    start_offset_ms: Required[Annotated[int, PropertyInfo(alias="startOffsetMs")]]
    """Offset in milliseconds from the start of the call when the tool was invoked"""

    description: str
    """Description of when the tool should be invoked"""

    end_offset_ms: Annotated[int, PropertyInfo(alias="endOffsetMs")]
    """
    Offset in milliseconds from the start of the call when the tool execution
    completed. Used to calculate duration of the tool execution
    """
